pub fn encode_get_taxi_stands(
input: GetTaxiStandsInput,
) -> Result<Request<Vec<u8>>, Error>Expand description
Returns detailed information of Taxi stands, such as location and whether it is barrier free.
Update freq: Monthly
pub fn encode_get_taxi_stands(
input: GetTaxiStandsInput,
) -> Result<Request<Vec<u8>>, Error>Returns detailed information of Taxi stands, such as location and whether it is barrier free.
Update freq: Monthly