pub fn get_taxi_stands_parts(
input: GetTaxiStandsInput,
) -> Result<RequestParts<()>, Error>Expand description
Returns detailed information of Taxi stands, such as location and whether it is barrier free.
Update freq: Monthly
pub fn get_taxi_stands_parts(
input: GetTaxiStandsInput,
) -> Result<RequestParts<()>, Error>Returns detailed information of Taxi stands, such as location and whether it is barrier free.
Update freq: Monthly